pub enum ExecuteMsg {
Transfer {
recipient: String,
amount: Uint128,
},
Burn {
amount: Uint128,
},
Send {
contract: String,
amount: Uint128,
msg: Binary,
},
Mint {
recipient: String,
amount: Uint128,
},
IncreaseAllowance {
spender: String,
amount: Uint128,
expires: Option<Expiration>,
},
DecreaseAllowance {
spender: String,
amount: Uint128,
expires: Option<Expiration>,
},
TransferFrom {
owner: String,
recipient: String,
amount: Uint128,
},
SendFrom {
owner: String,
contract: String,
amount: Uint128,
msg: Binary,
},
BurnFrom {
owner: String,
amount: Uint128,
},
}Variants
Transfer
Transfer is a base message to move tokens to another account without triggering actions
Burn
Burn is a base message to destroy tokens forever
Send
Send is a base message to transfer tokens to a contract and trigger an action on the receiving contract.
Mint
Only with the “mintable” extension. If authorized, creates amount new tokens and adds to the recipient balance.
IncreaseAllowance
Only with “approval” extension. Allows spender to access an additional amount tokens from the owner’s (env.sender) account. If expires is Some(), overwrites current allowance expiration with this one.
DecreaseAllowance
Only with “approval” extension. Lowers the spender’s access of tokens from the owner’s (env.sender) account by amount. If expires is Some(), overwrites current allowance expiration with this one.
TransferFrom
Only with “approval” extension. Transfers amount tokens from owner -> recipient
if env.sender has sufficient pre-approval.
SendFrom
Only with “approval” extension. Sends amount tokens from owner -> contract
if env.sender has sufficient pre-approval.
BurnFrom
Only with “approval” extension. Destroys tokens forever